@@ -88,13 +88,13 @@ def view(ctx, name, is_raw, is_yaml, is_args):
     """
     View details about a single template
 
-    Use the full name of the template including organization, 
+    Use the full name of the template including organization,
     category and version, i.e. [org]/[cat]/[name]/[version]
 
     If you omit the version the latest version is fetched.
     e.g. 'nextcode query templates view wxnc/system/acmg_scores'
 
-    You can also specify a glob pattern. e.g. 
+    You can also specify a glob pattern. e.g.
     'nextcode query templates view "wxnc/system/acmg_scores/1.4.*"'
     """
     svc = ctx.obj.service
@@ -149,8 +149,7 @@ def view(ctx, name, is_raw, is_yaml, is_args):
 @click.option('--replace', is_flag=True, default=False, help='Delete and replace existing template')
 @click.pass_context
 def add(ctx, filename, replace):
-    """Add a new template from yaml file.
-    """
+    """Add a new template from yaml file."""
     svc = ctx.obj.service
     try:
         full_name = svc.add_template_from_file(filename, replace=replace)
