@@ -93,8 +93,9 @@ def jobs(
         'estimated_cost',
         'status',
     ]
+    process_header = '#su/#ru/#fa/#ab/#co'
     if is_wide:
-        fields.extend(['desc', 'context', 'complete_date', 'pod', '#proc'])
+        fields.extend(['desc', 'context', 'complete_date', 'pod', process_header])
     if params_columns:
         for p in  params_columns.split(','):
             fields.append(f"param_{p}")
@@ -115,8 +116,13 @@ def jobs(
                 v = click.style(v, fg=col, bold=True)
             elif f == 'pod':
                 v = job.details.get('pod_name', v)
-            elif f == '#proc':
-                v = sum(job.details.get('process_stats', {}).values())
+            elif f == process_header:
+                submitted = job.details.get('process_stats', {}).get('SUBMITTED', 0)
+                completed = job.details.get('process_stats', {}).get('COMPLETED', 0)
+                running = job.details.get('process_stats', {}).get('STARTED', 0)
+                aborted = job.details.get('process_stats', {}).get('ABORTED', 0)
+                failed = job.details.get('process_stats', {}).get('FAILED', 0)
+                v = f'{submitted}/{running}/{failed}/{aborted}/{completed}'
             elif f == 'desc':
                 v = job.description or ""
                 if len(v) > 50:
